marktools.LilyPondComment
=========================

.. abjad-lineage:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment

.. autoclass:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.contents_string
   :noindex:

.. autoattribute:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.format_slot
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.attach
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__delattr__
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__ge__
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__gt__
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__le__
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__lt__
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.LilyPondComment.LilyPondComment.LilyPondComment.__repr__
   :noindex:
